@@ -16,7 +16,7 @@ Readonly::Scalar our $EMPTY_STR => q{};
 Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -250,7 +250,13 @@ L<Unicode::Char>.
 
 =head1 SEE ALSO
 
-L<Unicode::Block>.
+=over
+
+=item L<Unicode::Block>
+
+Class for unicode block manipulation.
+
+=back
 
 =head1 REPOSITORY
 
@@ -264,10 +270,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2013-2017 Michal Josef Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
